@@ -10,10 +10,11 @@ from robin_sd_upload import _version
 from robin_sd_upload.slack_interaction import slack_handler
 from robin_sd_upload.supportive_scripts import yaml_parser
 from robin_sd_upload.supportive_scripts import logger
-from supportive_scripts.validate import validate
-from supportive_scripts.create_zip import create_zip
-from supportive_scripts.remove_zip import remove_zip
-from supportive_scripts.check_upload_file import check_upload_file
+
+import robin_sd_upload.supportive_scripts.validate as validate
+import robin_sd_upload.supportive_scripts.create_zip as create_zip
+import robin_sd_upload.supportive_scripts.remove_zip as remove_zip
+import robin_sd_upload.supportive_scripts.check_upload_file as check_upload_file
 
 def arg_parser():
     parser = argparse.ArgumentParser(
